<?php

chdir(dirname(__DIR__));

date_default_timezone_set('America/Los_Angeles');
ini_set('max_execution_time', 0);
set_time_limit(0);
define( 'WP_USE_THEMES', false ); // Don't load theme support functionality
require( __DIR__ . '/../../../wp-load.php' );

function argv($args) {
    array_shift($args);
    $ret = array(
        'flags' => array(),
        'args'  => array(),
        'input' => array()
    );
    foreach($args as $arg) {
        list($name, $value) = explode('=', $arg);
        if(substr($name, 0, 2) === '--') {
            $ret['args'][str_replace('--', '', $name)] = $value;
        } elseif(substr($name, 0, 1) === '-' && empty($value)) {
            $ret['flags'][] = str_replace('-', '', $name);
        } elseif(substr($name, 0, 1) === '-' && !empty($value)) {
            $ret['args'][str_replace('-', '', $name)] = $value;
        } else {
            $ret['input'][] = $name;
        }
    }
    return $ret;
}

function processProducts($products)
{
    $productObj = new MDHQCRelayProductSync();
    foreach($products as $product) {
        if (empty($product->post_name) || empty($product->sku)) {
            continue;
        }

        $sku 	= $product->sku;
        $stock 	= $product->stock;
        $brand  = empty($product->brand) ? 'NO BRAND' : $product->brand;
        $name = $product->post_title . ' - ' . $sku . ' - ' . $brand;
        $slug = str_ireplace('__trashed','',$product->post_name);
        $nickname = str_ireplace('-',' ', $slug) . ', ' . $sku . ', ' . $brand;

        $inactive = true;
        if($product->post_status === 'publish' && $stock === 'instock') {
            $inactive = false;
        }
        $data_string = array(
            'name' 			=> $name, // update the title of the product
            'nicknames' 	=> $nickname,
            'vendor_code' 	=> $sku,
            'description' 	=> '',
            'class' 		=> 'NutrimentRx',
            'external_ref_id' => $product->ID,
            'inactive' 		=> $inactive,
            'site' => get_site_url(),
        );

        $productObj->postCurl('https://nutrimentrx.com/?receive_product_mdhqc=1', json_encode($data_string));
        usleep(20000);
    }

    return true;
}

$args = argv($argv);

if(empty($args['args']['datafile'])) {
    echo 'No data file passed' . "\n";
    exit;
}

$filePath = __DIR__ . "/input-files/" . $args['args']['datafile'];
if (!file_exists($filePath)) {
    echo "No file exist";
    exit;
}
global $wpdb;
if (strpos($args['args']['datafile'], '-products') !== false) {
    $products = file_get_contents($filePath);
    $products  = $wpdb->get_results(
        "SELECT `a`.`ID`, `a`.`post_title`, `a`.`post_status`, `a`.`post_name`, `b`.`meta_value` AS `sku`, `c`.`meta_value` AS `stock`, `t`.`name` as `brand`
                        FROM `{$wpdb->posts}` AS `a` 
                        LEFT JOIN `{$wpdb->postmeta}` AS `b` ON `a`.`ID` = `b`.`post_id` AND `b`.`meta_key` LIKE '_sku' 
                        LEFT JOIN `{$wpdb->postmeta}` AS `c` ON `a`.`ID` = `c`.`post_id` AND `c`.`meta_key` LIKE '_stock_status' 
                        LEFT JOIN `{$wpdb->term_relationships}` AS `tr` ON (`a`.`ID` = `tr`.`object_id`)
                        LEFT JOIN `{$wpdb->term_taxonomy}` AS `tt` ON (`tr`.`term_taxonomy_id` = `tt`.`term_taxonomy_id`)
                        LEFT JOIN `{$wpdb->terms}` AS `t` ON (`t`.`term_id` = `tt`.`term_id`)
                        WHERE `a`.`post_type` LIKE 'product' AND
                              `a`.`ID` IN (". $products .") AND
                              `tt`.`taxonomy` = 'product_brand'"
    );

    if (!empty($products)) {
        processProducts($products);
    }
    unlink($filePath);
    exit;
}

$startOffset = file_get_contents($filePath);
$products  = $wpdb->get_results(
    "SELECT `a`.`ID`, `a`.`post_title`, `a`.`post_status`, `a`.`post_name`, `b`.`meta_value` AS `sku`, `c`.`meta_value` AS `stock`, `t`.`name` as `brand`
                        FROM `{$wpdb->posts}` AS `a` 
                        LEFT JOIN `{$wpdb->postmeta}` AS `b` ON `a`.`ID` = `b`.`post_id` AND `b`.`meta_key` LIKE '_sku' 
                        LEFT JOIN `{$wpdb->postmeta}` AS `c` ON `a`.`ID` = `c`.`post_id` AND `c`.`meta_key` LIKE '_stock_status' 
                        LEFT JOIN `{$wpdb->term_relationships}` AS `tr` ON (`a`.`ID` = `tr`.`object_id`)
                        LEFT JOIN `{$wpdb->term_taxonomy}` AS `tt` ON (`tr`.`term_taxonomy_id` = `tt`.`term_taxonomy_id`)
                        LEFT JOIN `{$wpdb->terms}` AS `t` ON (`t`.`term_id` = `tt`.`term_id`)
                        WHERE `a`.`post_type` LIKE 'product' AND
                              `tt`.`taxonomy` = 'product_brand'
                                LIMIT {$startOffset}, 500"
                );

if (empty($products)) {
    unlink($filePath);
    exit;
}


processProducts($products);
$startOffset = $startOffset + 500;
file_put_contents($filePath, $startOffset);
$command = 'php ' . __DIR__ . '/cli.php --datafile=' . $args['args']['datafile'];
$pid = (int) shell_exec("nohup ".$command." > /dev/null 2>&1 & echo $!");
exit;
